Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorStephen Swaney <sswaney@centurytel.net>2004-04-08 02:42:02 +0400
committerStephen Swaney <sswaney@centurytel.net>2004-04-08 02:42:02 +0400
commit9cabf31ebc7a27173b527aaad80bfe6140fe3d5b (patch)
treedda29da35019a77947454a15e78abee8444a5b97 /source/blender/python/api2_2x/doc/Ipo.py
parenta93a6966b7a356199f63562dd7dfdd8a8dfdea43 (diff)
fix for bug #1115
This was a problem with the BezTriple type. Write access to BezTriple via 'pt' member did not work. Preferred method to access BPy type members, especially for write access, is via get*/set* methods. BezTriple.setPoints() will accept x,y coordinates as either a tuple or a list. Updated BezTriple section of Ipo module doc.
Diffstat (limited to 'source/blender/python/api2_2x/doc/Ipo.py')
-rw-r--r--source/blender/python/api2_2x/doc/Ipo.py12
1 files changed, 6 insertions, 6 deletions
diff --git a/source/blender/python/api2_2x/doc/Ipo.py b/source/blender/python/api2_2x/doc/Ipo.py
index 4a40331660f..f010f32dd52 100644
--- a/source/blender/python/api2_2x/doc/Ipo.py
+++ b/source/blender/python/api2_2x/doc/Ipo.py
@@ -260,22 +260,22 @@ class BezTriple:
"""
The BezTriple object
====================
- This object gives access to generic data from all beztriple objects in Blender.
- @cvar name: The Curve Data name.
- @cvar bezierPoints : The list of the Bezier points.
+ This object gives access to generic data from all beztriple objects in Blender. If an attribute is listed as being 'read-only' that means you cannot write to it. Use the set*() methods instead.
+ @cvar pt : a list of the [x,y] coordinates for knot point of this BezTriple. read-only.
+ @cvar vec : a list of the 3 points [ handle, knot, handle ] that comprise a BezTriple. See the getTriple() method for an example of the format. read-only.
"""
def getPoints():
"""
Returns the xy coordinates of the Bezier point.
@rtype: list of floats
@return: list of the x and y coordinates of the Bezier point.
"""
def setPoints(newval):
"""
- Sets the point xy coordinates.
- @type newval: tuple of (at least) 2 floats
+ Sets the point xy coordinates of the Bezier knot point.
+ @type newval: tuple of 2 floats
@param newval: the x and y coordinates of the new Bezier point.
@rtype: PyNone
@return: PyNone
@@ -260,22 +260,22 @@ class BezTriple:
def getPoints():
"""
- Returns the xy coordinates of the Bezier point.
+ Returns the xy coordinates of the Bezier knot point.